@@ -1,11 +1,13 @@
 class ClientUrls:
     LOGIN_URL='https://www.instagram.com/accounts/login/'
     NAV_USER='https://www.instagram.com/{}/'
+    NEW_DM = 'https://www.instagram.com/direct/new/'
     SEARCH_TAGS='https://www.instagram.com/explore/tags/{}/'
     FOLLOWERS_URL = 'https://www.instagram.com/{}/followers/'
     HOME_URL =  'https://www.instagram.com/'
     LOGIN_THEN_USER = 'https://www.instagram.com/accounts/login/?next=/{}/'
     SECURITY_CODE_URL = 'https://www.instagram.com/challenge/'
+    DM_URL  = 'https://www.instagram.com/direct/t/'
 
 
 class GraphUrls:
